@@ -1,5 +1,7 @@
-from cacheback.function import FunctionJob
+from functools import wraps
+from django.utils.decorators import available_attrs
 
+from cacheback.function import FunctionJob
 
 def cacheback(lifetime=None, fetch_on_miss=None, job_class=None):
     """
@@ -13,6 +15,8 @@ def cacheback(lifetime=None, fetch_on_miss=None, job_class=None):
     job = job_class(lifetime, fetch_on_miss)
 
     def _wrapper(fn):
+        # using available_attrs to work around http://bugs.python.org/issue3445
+        @wraps(fn, assigned=available_attrs(fn))
         def __wrapper(*args, **kwargs):
             return job.get(fn, *args, **kwargs)
         # Assign reference to unwrapped function so that we can access it
